/**
 *
 * \file main.c
 *  A very simple skeleton code to start from:
 *	1. initializes hardware, debugger and nanostack
 *	2. creates a task and starts scheduler
 *	3. when the application is started it reads the initial 
 *	   time and starts blinking the LED.			
 *  Derived from the Sensionde's "nano_skeleton.c" 	
 *  Author: Matej Kristan (2008)
 */

/* Standard includes. */
#include <stdlib.h>
#include <string.h>
#include <sys/inttypes.h>

/* Scheduler includes. */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"

/* NanoStack includes */
#include "stack.h"
#include "socket.h"
#include "debug.h"
#include "control_message.h"

/* Platform includes */
#include "uart.h"
#include "rf.h"
#include "bus.h"
#include "dma.h"
#include "timer.h"
#include "gpio.h"

// global variables
portTickType	scan_start ;


// application
static void vAppTask( int8_t *pvParameters );
 
/* Main task, initialize hardware and start the FreeRTOS scheduler */
int main( void )
{
	/* Initialize the Nano hardware */
	LED_INIT(); // initialize leds
	bus_init() ; // initialize hardware
	debug_init(115200); // initialize debug stuff
	stack_init(); // initialize stack variables
	
	/* Setup the application task and start the scheduler */
	xTaskCreate( vAppTask, "App", configMAXIMUM_STACK_SIZE, NULL, 
	             (tskIDLE_PRIORITY + 2 ), ( xTaskHandle * )NULL ) ;
	vTaskStartScheduler();
	
	/* Scheduler has taken control, next vAppTask starts executing. */

	return 0;
}

/** 
 * Skeleton application task 
 */
static void vAppTask( int8_t *pvParameters )
{
	pvParameters ; // just so that the compiler doesn't complain.
	/* Start the debug UART at 115k */
	
	// message with leds that we are inside the application!
	debug("Started the vAppTask!\r\n");
	LED1_ON() ;
	// tukaj dodajte kodo, ki zakasni za 500ms !
	LED1_OFF() ;
	
	// read the time
	scan_start = xTaskGetTickCount() ;
	
	// enter infinite loop 
	for (;;) {
	   /* here comes the main code */
	 
		
	  /* end of the main code */	
	// Tukaj dodajte kodo, zakasni za 500ms, in preklopi stanje Ledici 2
	}	

}